@@ -2,16 +2,15 @@
 
 /* SPDX-License-Identifier: GPL-3.0-or-later */
 
-#include <chrono>
-#include <utility>
-#include <vector>
-
 namespace examples
 {
 struct ExponentialSmoothing
 {
   static constexpr auto name() { return "Exponential Smoothing"; }
   static constexpr auto c_name() { return "avnd_expsmooth"; }
+  static constexpr auto author() { return "Jean-Michaël Celerier"; }
+  static constexpr auto category() { return "Control/Mappings"; }
+  static constexpr auto description() { return "Simplest real-time value smoothing"; }
   static constexpr auto uuid() { return "971739ae-14a3-4283-b0a0-96dbd367ce66"; }
 
   struct
