@@ -47,7 +47,7 @@ try
 #endif
   return 0;
 }
-catch (const libremidi::midi_exception& error)
+catch (const std::exception& error)
 {
   std::cerr << error.what() << std::endl;
   return EXIT_FAILURE;
