@@ -1,5 +1,7 @@
 #pragma once
-#include <ossia/dataflow/execution/execution_policy.hpp>
+#include <ossia/dataflow/execution/local_state_execution_policy.hpp>
+#include <ossia/detail/flat_map.hpp>
+#include <ossia/editor/state/flat_vec_state.hpp>
 
 namespace ossia
 {
