@@ -1,7 +1,9 @@
 #pragma once
 #include <ossia/detail/logger.hpp>
 
-#include <boost/asio/high_resolution_timer.hpp>
+#include <boost/asio/steady_timer.hpp>
+#include <boost/asio/strand.hpp>
+#include <boost/asio/use_future.hpp>
 
 namespace ossia
 {
@@ -9,9 +11,14 @@ namespace ossia
 class timer
 {
 public:
+  template <typename Executor>
+  explicit timer(boost::asio::strand<Executor>& ctx)
+      : m_timer{ctx}
+  {
+  }
+
   explicit timer(boost::asio::io_context& ctx)
-      : m_ctx{&ctx}
-      , m_timer{ctx}
+      : m_timer{boost::asio::make_strand(ctx)}
   {
   }
 
@@ -29,26 +36,33 @@ public:
   {
     m_timer.expires_from_now(m_delay);
     m_timer.async_wait([this, ff = std::move(f)](auto ec) {
-      if(ec)
+      if(ec == boost::asio::error::operation_aborted)
+        return;
+      else if(ec)
       {
         ossia::logger().error("timer error: {}", ec.message());
         return;
       }
-
-      ff();
-      this->start(std::move(ff));
+      else
+      {
+        ff();
+        this->start(std::move(ff));
+      }
     });
   }
 
   void stop()
   {
-    m_ctx->post([tm = std::make_shared<boost::asio::high_resolution_timer>(
-                     std::move(m_timer))]() mutable { tm->cancel(); });
+    boost::asio::dispatch(
+        m_timer.get_executor(), [tm = std::make_shared<boost::asio::steady_timer>(
+                                     std::move(m_timer))]() mutable { tm->cancel(); });
+    std::future<void> wait
+        = boost::asio::dispatch(m_timer.get_executor(), boost::asio::use_future);
+    wait.get();
   }
 
 private:
-  boost::asio::io_context* m_ctx{};
-  boost::asio::high_resolution_timer m_timer;
+  boost::asio::steady_timer m_timer;
   std::chrono::milliseconds m_delay{};
 };
 
