@@ -12,6 +12,12 @@ namespace ossia::net
 class OSSIA_EXPORT dmxusbpro_protocol final : public dmx_output_protocol_base
 {
 public:
+  enum devices
+  {
+    dmx_usb_pro_mk1 = 1,
+    dmx_usb_pro_mk2 = 2,
+    open_dmx_usb = 3,
+  };
   dmxusbpro_protocol(
       ossia::net::network_context_ptr, const dmx_config& conf,
       const ossia::net::serial_configuration& socket, int version);
@@ -21,10 +27,11 @@ public:
   void set_device(ossia::net::device_base& dev) override;
 
 private:
-  void update_function(uint8_t command);
+  void update_function_dmxusbpro(uint8_t command);
+  void update_function_opendmx();
 
   boost::asio::serial_port m_port;
-  int m_version = 1;
+  int m_version = devices::dmx_usb_pro_mk1;
 };
 }
 #endif
