@@ -196,7 +196,7 @@ struct setup_Impl0
   operator()(Field& param, avnd::predicate_index<N> np, avnd::field_index<NField> nf)
   {
     if(auto inlet
-       = dynamic_cast<Process::ControlInlet*>(modelPort<Node>(element.inlets(), NField)))
+       = qobject_cast<Process::ControlInlet*>(modelPort<Node>(element.inlets(), NField)))
     {
       // Initialize the control with the current value of the inlet if it is not an optional
       if constexpr(!requires { param.value.reset(); })
@@ -816,11 +816,22 @@ public:
 
     if constexpr(avnd::has_processor_to_gui_bus<Node>)
     {
-      eff.send_message = [this](auto b) mutable {
-        this->in_edit([this, bb = std::move(b)]() mutable {
-          if(this->process().to_ui)
-            MessageBusSender{this->process().to_ui}(std::move(bb));
-        });
+      eff.send_message = [this]<typename T>(T&& b) mutable {
+        if constexpr(sizeof(this) + sizeof(b) < Execution::ExecutionCommand::max_storage)
+        {
+          this->in_edit([this, bb = std::move(b)]() mutable {
+            if(this->process().to_ui)
+              MessageBusSender{this->process().to_ui}(std::move(bb));
+          });
+        }
+        else
+        {
+          this->in_edit(
+              [this, bb = std::make_unique<std::decay_t<T>>(std::move(b))]() mutable {
+            if(this->process().to_ui)
+              MessageBusSender{this->process().to_ui}(*std::move(bb));
+          });
+        }
       };
     }
   }
